@@ -141,7 +141,7 @@ prv_metadata_mapping = {
 
 
 prv_data_mapping = {
-    "prove_nr": {"index": 0, "dtype": lambda x: int(x) if x.isdigit() else np.nan},
+    "prove_nr": {"index": 0, "dtype": str},
     "symbol": {"index": 1, "dtype": int},
     "dybde": {"index": 2, "dtype": float},
     "w": {"index": 3, "dtype": float},
